@@ -1,7 +1,7 @@
 from typing import List, Iterator
 
 from pyot.conf.model import models
-from pyot.core.functional import cache_indexes, lazy_property
+from pyot.core.functional import cache_indexes, lazy_property, empty
 from pyot.utils.lol.cdragon import abs_url, sanitize_description
 from .base import PyotCore
 
@@ -23,7 +23,7 @@ class Rune(PyotCore):
         rules = {"cdragon_rune_full": ["version", "locale", "?id"]}
         renamed = {"major_change_patch_version": "major_patch", "long_desc": "long_description", "short_desc": "description"}
 
-    def __init__(self, id: int = None, version: str = models.lol.DEFAULT_VERSION, locale: str = models.lol.DEFAULT_LOCALE):
+    def __init__(self, id: int = empty, version: str = models.lol.DEFAULT_VERSION, locale: str = models.lol.DEFAULT_LOCALE):
         self.initialize(locals())
 
     @cache_indexes
