@@ -1,4 +1,5 @@
 from pyot.conf.model import models
+from pyot.core.functional import empty
 from .base import PyotCore
 
 
@@ -13,7 +14,7 @@ class Account(PyotCore):
             "account_v1_by_riot_id": ["game_name", "tag_line"],
         }
 
-    def __init__(self, puuid: str = None, game_name: str = None, tag_line: str = None, region: str = models.riot.DEFAULT_REGION):
+    def __init__(self, puuid: str = empty, game_name: str = empty, tag_line: str = empty, region: str = models.riot.DEFAULT_REGION):
         self.initialize(locals())
 
     def active_shard(self, game: str):
@@ -28,7 +29,7 @@ class ActiveShard(PyotCore):
     class Meta(PyotCore.Meta):
         rules = {"account_v1_active_shard": ["puuid", "game"]}
 
-    def __init__(self, puuid: str = None, game: str = None, region: str = models.riot.DEFAULT_REGION):
+    def __init__(self, puuid: str = empty, game: str = empty, region: str = models.riot.DEFAULT_REGION):
         self.initialize(locals())
 
     @property
